@@ -45,6 +45,7 @@
 #'\item{polr}{Proportional odds model (ordered, >=2 levels)}
 #'\item{lda}{Linear discriminant analysis (factor, >= 2 categories)}
 #'\item{cart}{Classification and regression tress (any)}
+#'\item{ri}{Random indicator method for nonignorable data (numeric)}
 #'\item{sample}{Random sample from the observed values (any)} }
 #'
 #'These corresponding functions are coded in the \code{mice} library under
@@ -157,7 +158,8 @@
 #'@return Returns an S3 object of class \code{\link[=mids-class]{mids}} (multiply imputed data set)
 #'@author Stef van Buuren \email{stef.vanbuuren@@tno.nl}, Karin
 #'Groothuis-Oudshoorn \email{c.g.m.oudshoorn@@utwente.nl}, 2000-2010, with
-#'contributions of Alexander Robitzsch, Gerko Vink, Roel de Jong, Jason Turner,
+#'contributions of Alexander Robitzsch, Gerko Vink, Shahab Jolani, 
+#'Roel de Jong, Jason Turner, Lisa Doove, 
 #'John Fox, Frank E. Harrell, and Peter Malewski.
 #'@seealso \code{\link[=mids-class]{mids}}, \code{\link{with.mids}},
 #'\code{\link{set.seed}}, \code{\link{complete}}
@@ -185,6 +187,11 @@
 #'multiple imputation strategies for the statistical analysis of incomplete
 #'data sets.} Dissertation. Rotterdam: Erasmus University.
 #'@keywords iteration
+#'@import MASS nnet
+#'@importFrom stats lm glm
+#'@importFrom utils packageDescription
+#'@importFrom graphics plot
+#'@importFrom rpart rpart rpart.control
 #'@examples
 #'
 #'
@@ -264,6 +271,10 @@ mice <- function(data, m = 5, method = vector("character", length = ncol(data)),
             stop(paste("The predictorMatrix has", nrow(pred), "rows and", ncol(pred), "columns. Both should be", nvar, "."))
         dimnames(pred) <- list(varnames, varnames)
         diag(pred) <- 0
+        
+        ## stop if there is a class variable with missing data # SvB 25apr13
+        isclassvar <- apply(pred == -2, 2, any)
+        
         for (j in 1:nvar) {
             if (method[j] == "" & any(pred[, j] != 0) & nmis[j] > 0) {
                 out <- varnames[j]
@@ -271,10 +282,11 @@ mice <- function(data, m = 5, method = vector("character", length = ncol(data)),
                 pred[, j] <- 0
                 vis <- vis[vis != j]
                 post[j] <- ""
+                if (isclassvar[j]) stop("Removed an incomplete class variable.")  ## SvB 25apr13
             }
             if (nmis[j] == 0 & any(pred[j, ] != 0)) 
                 pred[j, ] <- 0
-        }
+        }        
         
         setup$predictorMatrix <- pred
         setup$visitSequence <- vis
@@ -336,7 +348,7 @@ mice <- function(data, m = 5, method = vector("character", length = ncol(data)),
             mj <- method[j]
             mlist <- list(m1 = c("logreg", "logreg.boot", "polyreg", "lda", "polr"), 
                           m2 = c("norm", "norm.nob", "norm.predict", "norm.boot", "mean", 
-                                 "2l.norm", "2L.norm", "2l.pan", "2L.pan", "2lonly.pan", "quadratic"), 
+                                 "2l.norm", "2L.norm", "2l.pan", "2L.pan", "2lonly.pan", "quadratic", "ri"), 
                           m3 = c("norm", "norm.nob", "norm.predict", "norm.boot", "mean", 
                                  "2l.norm", "2L.norm", "2l.pan", "2L.pan", "2lonly.pan", "quadratic", "logreg", "logreg.boot"))
             
@@ -361,10 +373,16 @@ mice <- function(data, m = 5, method = vector("character", length = ncol(data)),
         meth <- setup$method
         vis <- setup$visitSequence
         
+        ## stop if the class variable is a factor 25apr2013
+        isclassvar <- apply(pred == -2, 2, any)
+        for (j in 1:nvar) {
+            if (isclassvar[j] & is.factor(data[,j])) 
+            stop(paste("Class variable (column ",j,") cannot be factor. Convert to numeric by as.integer()",sep=""))        
+        }
         ## remove constant variables but leave passive variables untouched
         for (j in 1:nvar) {
             if (!is.passive(meth[j])) {
-                v <- var(data[, j], na.rm = TRUE)
+                v <- ifelse(is.character(data[,j]), NA, var(data[, j], na.rm = TRUE))
                 if (allow.na) {
                   constant <- FALSE  # SvB 10/3/2011
                   if (!is.na(v)) 
@@ -386,7 +404,7 @@ mice <- function(data, m = 5, method = vector("character", length = ncol(data)),
                   vis <- vis[vis != j]
                   post[j] <- ""
                 }
-            }
+            }                    
         }
         
         ## remove collinear variables
@@ -415,7 +433,7 @@ mice <- function(data, m = 5, method = vector("character", length = ncol(data)),
                 }
             }
         }
-        
+                
         setup$predictorMatrix <- pred
         setup$visitSequence <- vis
         setup$post <- post
@@ -436,7 +454,7 @@ mice <- function(data, m = 5, method = vector("character", length = ncol(data)),
     if (sum(nmis) == 0) 
         stop("No missing values found")
     varnames <- dimnames(data)[[2]]
-    
+        
     ## list for storing current computational state
     state <- list(it = 0, im = 0, co = 0, dep = "", meth = "", log = FALSE)
     
